# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from marketplace_server_connector.models.provider import Provider

class ProductIn(BaseModel):
    """
    ProductIn
    """
    portal_to_marketplace_id: StrictInt = Field(...)
    provider: Provider = Field(...)
    external_product_id: StrictStr = Field(...)
    title: Optional[StrictStr] = ''
    __properties = ["portal_to_marketplace_id", "provider", "external_product_id", "title"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProductIn:
        """Create an instance of ProductIn from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProductIn:
        """Create an instance of ProductIn from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ProductIn.parse_obj(obj)

        _obj = ProductIn.parse_obj({
            "portal_to_marketplace_id": obj.get("portal_to_marketplace_id"),
            "provider": obj.get("provider"),
            "external_product_id": obj.get("external_product_id"),
            "title": obj.get("title") if obj.get("title") is not None else ''
        })
        return _obj


