# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class Provider(str, Enum):
    """
    Provider
    """

    """
    allowed enum values
    """
    DIGISTORE = 'digistore'
    STRIPE = 'stripe'
    THRIVECART = 'thrivecart'
    COPECART = 'copecart'
    ELOPAGE = 'elopage'
    FAPI = 'fapi'
    ZAPIER = 'zapier'
    UPGATES = 'upgates'
    AFFILICON = 'affilicon'
    APPSTORE = 'appstore'
    GOOGLE_PLAY = 'google_play'
    API = 'api'

    @classmethod
    def from_json(cls, json_str: str) -> Provider:
        """Create an instance of Provider from a JSON string"""
        return Provider(json.loads(json_str))


